| Title: | 'RStudio' Addin to Paste the Clipboard as a Comment Block or a 'roxygen' Block |
|---|---|
| Description: | Provides a 'RStudio' addin allowing to paste the content of the clipboard as a comment block or as 'roxygen' lines. This is very useful to insert an example in the 'roxygen' block. |
| Authors: | Stéphane Laurent |
| Maintainer: | Stéphane Laurent <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.1 |
| Built: | 2026-05-28 10:06:31 UTC |
| Source: | https://github.com/stla/pasteascomment |
Provides a 'RStudio' addin allowing to paste a selection as a comment block or a 'roxygen' block.
This package does not provide any function, only a 'RStudio' addin.
Stéphane Laurent.
Maintainer: Stéphane Laurent <[email protected]>