Welcome to ClientVPS Mirrors

Help for package pasteAsComment
Type: Package
Title: 'RStudio' Addin to Paste the Clipboard as a Comment Block or a 'roxygen' Block
Version: 0.2.1
Author: Stéphane Laurent
Maintainer: Stéphane Laurent <laurent_step@outlook.fr>
Description: Provides a 'RStudio' addin allowing to paste the content of the clipboard as a comment block or as 'roxygen' lines. This is very useful to insert an example in the 'roxygen' block.
License: GPL-3
Encoding: UTF-8
Imports: rstudioapi, clipr
URL: https://github.com/stla/pasteAsComment
BugReports: https://github.com/stla/pasteAsComment/issues
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-09-14 09:49:48 UTC; SDL96354
Repository: CRAN
Date/Publication: 2023-09-14 12:10:06 UTC

Paste as a comment block or as a 'roxygen' block

Description

Provides a 'RStudio' addin allowing to paste a selection as a comment block or a 'roxygen' block.

Details

This package does not provide any function, only a 'RStudio' addin.

Author(s)

Stéphane Laurent.

Maintainer: Stéphane Laurent <laurent_step@outlook.fr>

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.